==> sheep_0.0.2-1.tar.gz: sheep-0.0.2/soundengine.cpp <==
#include <soundengine.h>
#include <iostream>

SoundEngine::SoundEngine()
{

	bah1 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah1.mp3"));
	QWidget::connect(bah1,SIGNAL(aboutToFinish()),bah1,SLOT(pause()));

	bah2 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah2.mp3"));
	QWidget::connect(bah2,SIGNAL(aboutToFinish()),bah2,SLOT(pause()));
	
	bah3 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah3.mp3"));
	QWidget::connect(bah3,SIGNAL(aboutToFinish()),bah3,SLOT(pause()));
	
	bah4 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah4.mp3"));
	QWidget::connect(bah4,SIGNAL(aboutToFinish()),bah4,SLOT(pause()));

	bah5 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah5.mp3"));
	QWidget::connect(bah5,SIGNAL(aboutToFinish()),bah5,SLOT(pause()));
	
	bah6 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah6.mp3"));
	QWidget::connect(bah6,SIGNAL(aboutToFinish()),bah6,SLOT(pause()));

	bah7 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah7.mp3"));
	QWidget::connect(bah7,SIGNAL(aboutToFinish()),bah7,SLOT(pause()));
	
		

}


Phonon::MediaObject* SoundEngine::bah1=NULL;
Phonon::MediaObject* SoundEngine::bah2=NULL;
Phonon::MediaObject* SoundEngine::bah3=NULL;
Phonon::MediaObject* SoundEngine::bah4=NULL;
Phonon::MediaObject* SoundEngine::bah5=NULL;
Phonon::MediaObject* SoundEngine::bah6=NULL;
Phonon::MediaObject* SoundEngine::bah7=NULL;
Phonon::MediaObject* SoundEngine::background=NULL;

void* SoundEngine::playSingleBah(void *)
{
	qsrand(time(NULL));
	int option=qrand()%7;
	
	std::cout<<option<<std::endl;
	
	if (option==0)
	{

		bah1->play();
		bah1->seek(1);
		return 0;

	}

	if (option==1)
	{

		bah2->play();
		bah2->seek(1);
		return 0;

	}
	if (option==2)
	{

		bah3->play();
		bah3->seek(1);
		return 0;

	}
	if (option==3)
	{

		bah4->play();
		bah4->seek(1);
		return 0;

	}
	if (option==4)
	{

		bah5->play();
		bah5->seek(1);
		return 0;

	}
	if (option==5)
	{

		bah6->play();
		bah6->seek(1);
		return 0;

	}
	if (option==6)
	{

		bah7->play();
		bah7->seek(1);
		return 0;

	}

	
}

void* SoundEngine::playBackground(void *)
{

//	background->play();
}

==> sheep_0.0.2-2.tar.gz: sheep-0.0.2/soundengine.cpp <==
#include <soundengine.h>
#include <iostream>

SoundEngine::SoundEngine()
{

	bah1 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah1.mp3"));
	QWidget::connect(bah1,SIGNAL(aboutToFinish()),bah1,SLOT(pause()));

	bah2 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah2.mp3"));
	QWidget::connect(bah2,SIGNAL(aboutToFinish()),bah2,SLOT(pause()));
	
	bah3 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah3.mp3"));
	QWidget::connect(bah3,SIGNAL(aboutToFinish()),bah3,SLOT(pause()));
	
	bah4 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah4.mp3"));
	QWidget::connect(bah4,SIGNAL(aboutToFinish()),bah4,SLOT(pause()));

	bah5 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah5.mp3"));
	QWidget::connect(bah5,SIGNAL(aboutToFinish()),bah5,SLOT(pause()));
	
	bah6 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah6.mp3"));
	QWidget::connect(bah6,SIGNAL(aboutToFinish()),bah6,SLOT(pause()));

	bah7 =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/bah7.mp3"));
	QWidget::connect(bah7,SIGNAL(aboutToFinish()),bah7,SLOT(pause()));
	
	background =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource("/home/opt/sheep/sounds/background.mp3"));
		

}


Phonon::MediaObject* SoundEngine::bah1=NULL;
Phonon::MediaObject* SoundEngine::bah2=NULL;
Phonon::MediaObject* SoundEngine::bah3=NULL;
Phonon::MediaObject* SoundEngine::bah4=NULL;
Phonon::MediaObject* SoundEngine::bah5=NULL;
Phonon::MediaObject* SoundEngine::bah6=NULL;
Phonon::MediaObject* SoundEngine::bah7=NULL;
Phonon::MediaObject* SoundEngine::background=NULL;

void* SoundEngine::playSingleBah(void *)
{
	qsrand(time(NULL));
	int option=qrand()%7;
	
	std::cout<<option<<std::endl;
	
	if (option==0)
	{

		bah1->play();
		bah1->seek(1);
		return 0;

	}

	if (option==1)
	{

		bah2->play();
		bah2->seek(1);
		return 0;

	}
	if (option==2)
	{

		bah3->play();
		bah3->seek(1);
		return 0;

	}
	if (option==3)
	{

		bah4->play();
		bah4->seek(1);
		return 0;

	}
	if (option==4)
	{

		bah5->play();
		bah5->seek(1);
		return 0;

	}
	if (option==5)
	{

		bah6->play();
		bah6->seek(1);
		return 0;

	}
	if (option==6)
	{

		bah7->play();
		bah7->seek(1);
		return 0;

	}

	
}

void* SoundEngine::playBackground(void *)
{

	background->play();
}
